Learn R Programming

czechrates (version 0.2.4)

repo2w: Two-week Repo Rate

Description

A function returning data frame of two-week repo rate, as set by ČNB.

Usage

repo2w(date = Sys.Date() - 1)

Value

data frame - first column is date, second is relevant two-week repo rate (the primary CZK policy rate)

Arguments

date

Date of fixing as date, default is yesterday.

Details

The function expects date input, and returns data frame of two columns - date, and relevant repo rate. It does not require maturity argument, as maturity is by definition 2W.

Repo rates are reported as fractions, i.e. not as percentages (i.e. 1% is reported as .01, not 1).

A single result will be reported for all dates higher than December 8th, 1995.

Examples

Run this code
# \donttest{
  repo2w(as.Date("2002-08-12"))
# }

Run the code above in your browser using DataLab